@@ -1,6 +1,6 @@
 import html
 from pathlib import Path
-from typing import Tuple, List
+from typing import Tuple, List, Optional
 
 import streamlit as st
 from PIL import Image
@@ -17,7 +17,6 @@ div = H.div
 px = unit.px
 rem = unit.rem
 em = unit.em
-DEBUG = True
 
 
 def ProjectBean_hash(self):
@@ -49,34 +48,34 @@ def get_client(token: str):
     return StreamlitSherpaClient.from_token(token)
 
 
-@st.experimental_memo(suppress_st_warning=True, show_spinner=False)
-def get_cached_projects(token: str) -> List[ProjectBean]:
-    if DEBUG:
+@st.experimental_memo(suppress_st_warning=True, show_spinner=False, ttl=24 * 3600)
+def get_cached_projects(token: str, debug: bool = False) -> List[ProjectBean]:
+    if debug:
         st.write("Cache miss: get_cached_projects(", token, ") ran")
     return get_client(token).get_projects()
 
 
-@st.experimental_memo(suppress_st_warning=True, show_spinner=False)
-def get_cached_sample_doc(token: str, project: str) -> Document:
-    if DEBUG:
+@st.experimental_memo(suppress_st_warning=True, show_spinner=False, ttl=24 * 3600)
+def get_cached_sample_doc(token: str, project: str, debug: bool = False) -> Document:
+    if debug:
         st.write("Cache miss: get_cached_sample_doc(", token, ",", project, ") ran")
     return get_client(token).get_sample_doc(project)
 
 
-@st.experimental_memo(suppress_st_warning=True, show_spinner=False)
+@st.experimental_memo(suppress_st_warning=True, show_spinner=False, ttl=24 * 3600)
 def get_cached_annotators(token: str, project: str, annotator_types: Tuple[str] = None,
-                          favorite_only: bool = False):
-    if DEBUG:
+                          favorite_only: bool = False, debug: bool = False):
+    if debug:
         st.write("Cache miss: get_cached_annotators(", token, ",", project, ",", annotator_types, ",", favorite_only,
                  ") ran")
     return get_client(token).get_annotators(project, annotator_types, favorite_only)
 
 
-@st.experimental_memo(suppress_st_warning=True, show_spinner=False)
+@st.experimental_memo(suppress_st_warning=True, show_spinner=False, ttl=24 * 3600)
 def get_cached_annotator_by_label(token: str, project: str, label: str,
                                   annotator_types: Tuple[str] = None,
-                                  favorite_only: bool = False):
-    if DEBUG:
+                                  favorite_only: bool = False, debug: bool = False):
+    if debug:
         st.write("Cache miss: get_cached_annotator_by_label(", token, ",", project, ",", label, ",",
                  annotator_types, ",",
                  favorite_only, ") ran")
@@ -87,9 +86,9 @@ def get_cached_annotator_by_label(token: str, project: str, label: str,
     return None
 
 
-@st.experimental_memo(suppress_st_warning=True, show_spinner=False)
-def get_cached_project_by_label(token: str, label: str) -> ProjectBean:
-    if DEBUG:
+@st.experimental_memo(suppress_st_warning=True, show_spinner=False, ttl=24 * 3600)
+def get_cached_project_by_label(token: str, label: str, debug: bool = False) -> Optional[ProjectBean]:
+    if debug:
         st.write("Cache miss: get_cached_project_by_label(", token, ",", label, ") ran")
     projects = get_cached_projects(token)
     for p in projects:
